@@ -1,5 +1,5 @@
 package TreePath;
-
+$TreePath::VERSION = '0.16';
 use utf8;
 use Moose;
 with 'MooseX::Object::Pluggable';
@@ -9,8 +9,6 @@ use Config::JFDI;
 use Carp qw/croak/;
 use Data::Dumper;
 
-our $VERSION = '0.15';
-
 subtype MyConf => as 'HashRef';
 coerce 'MyConf'
   => from 'Str' => via {
@@ -37,11 +35,6 @@ has conf => ( is => 'rw',
                   $self->debug($self->config->{'debug'})
                     if ( ! defined $self->debug && defined $self->config->{'debug'} );
 
-                  $self->_search_field($self->config->{backend}->{args}->{search_field})
-                      if defined $self->config->{backend}->{args}->{search_field};
-                  $self->_parent_field($self->config->{backend}->{args}->{parent_field})
-                      if defined $self->config->{backend}->{args}->{parent_field};
-
                   $self->_load_backend if ! $self->can('backend');
                 }
                 # it's a hash
@@ -98,12 +91,6 @@ has _search_field => (
                 default  => sub{ 'name' },
                   );
 
-has _parent_field => (
-                is       => 'rw',
-                isa      => 'Str',
-                default  => sub{ 'parent' },
-                  );
-
 has tree => (
                 isa      => "HashRef",
                 is       => "rw",
@@ -197,17 +184,32 @@ sub _build_tree {
               $node->{$col} = $newarray;
           }
       }
-      my $parent_field;
-      if ( defined $self->config && defined $self->config->{backend}->{args}->{sources_name}->{$node->{source}}->{parent_field}) {
-          $parent_field = $self->config->{backend}->{args}->{sources_name}->{$node->{source}}->{parent_field};
-      }
-      else {
-          $parent_field = 'parent';
-      }
+
+      my $parent_field = $self->_parent_field($node);
       $self->add($node, $node->{$parent_field});
   }
 }
 
+sub _parent_field{
+    my $self = shift;
+    my $node = shift;
+
+    my $source;
+    if ( ref($node)) {
+        $source = $node->{$self->_source_field};
+    }
+    else {
+        $source = $node;
+    }
+    my $parent_field;
+    if ( defined $self->config && defined $self->config->{backend}->{args}->{sources_name}->{$source}->{parent_field}) {
+        $parent_field = $self->config->{backend}->{args}->{sources_name}->{$source}->{parent_field};
+    }
+    else {
+        $parent_field = 'parent';
+    }
+    return $parent_field;
+}
 # sub  _bckd_create {
 #     my $self = shift;
 #     my $node = shift;
@@ -261,25 +263,25 @@ sub _remove_child_father{
 }
 
 
-sub _clone_node {
-    my $self = shift;
-    my $node = shift;
+# sub _clone_node {
+#     my $self = shift;
+#     my $node = shift;
 
-    my $clone = {};
-    foreach my $k (keys %$node) {
-        if ( $k eq 'parent'){
-            if ( $node->{'parent'}) {
-                $clone->{$self->_parent_field} = $node->{$k}->{id};
-            }
-            # is root
-            else {
-                $clone->{$self->_parent_field} = 0;
-            }
-        }
-        else { $clone->{$k} = $node->{$k} }
-    }
-    return $clone;
-}
+#     my $clone = {};
+#     foreach my $k (keys %$node) {
+#         if ( $k eq 'parent'){
+#             if ( $node->{'parent'}) {
+#                 $clone->{$self->_parent_field} = $node->{$k}->{id};
+#             }
+#             # is root
+#             else {
+#                 $clone->{$self->_parent_field} = 0;
+#             }
+#         }
+#         else { $clone->{$k} = $node->{$k} }
+#     }
+#     return $clone;
+# }
 
 
 sub _key_obj {
@@ -474,14 +476,14 @@ sub traverse {
     return 0 if ( ! &$funcref( $node, $args ) )
   }
 
-  my $key_children = $self->_key_children($node, $node->{parent});
-  if(defined($node->{$key_children})) {
-
-    foreach my $child ( @{$node->{$key_children}} ) {
-      return 0 if ( ! &$funcref( $child, $args ) );
-      $args->{_count}++;
-      $self->traverse( $child, $funcref, $args );
-    }
+  foreach my $field ( keys %$node) {
+      if ( ref($node->{$field}) eq 'ARRAY' ) {
+        foreach my $child ( @{$node->{$field}} ) {
+          return 0 if ( ! &$funcref( $child, $args ) );
+          $args->{_count}++;
+          $self->traverse( $child, $funcref, $args );
+        }
+      }
   }
 
   return $args->{_each_nodes} if $nofunc;
@@ -503,6 +505,7 @@ sub del {
 
       # traverse child branches and delete it
       my $nodes = $self->traverse($node);
+
       push(@deleted,map { delete $self->tree->{$self->_key_obj($_)} } @$nodes);
       #$self->_bckd_delete($nodes, "delete " . @$nodes . " node(s)");
   }
@@ -611,6 +614,9 @@ TreePath - Simple Tree Path!
  # a node can have children
  my $children = $root->{children};
 
+ # or children from another source
+ my $children = $root->{children_Comment};
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new($method => $value)
